@@ -41,7 +41,8 @@ dominating.character <- function(catlg) dominating(FrF2::catlg[catlg])
 
 res.catlg <- function(catlg) sapply(catlg, function(obj) obj$res)
 nclear.2fis.catlg <- function(catlg) sapply(catlg, function(obj) obj$nclear.2fis)
-clear.2fis.catlg <- function(catlg) lapply(catlg, function(obj) obj$clear.2fis)
+## takes care of designs with a single 2fi, for which this is a vector (e.g. in catlg128.21; April 2020)
+clear.2fis.catlg <- function(catlg) lapply(catlg, function(obj) matrix(obj$clear.2fis, nrow=2))
 all.2fis.clear.catlg <- function(catlg) lapply(catlg, function(obj) obj$all.2fis.clear)
 nfac.catlg <- function(catlg) sapply(catlg, function(obj) obj$nfac)
 nruns.catlg <- function(catlg) sapply(catlg, function(obj) obj$nruns)
