@@ -127,4 +127,4 @@ run.order(FrF2(8,3,blocks=2,bbreps=2,wbreps=2,repeat.only=TRUE,randomize=TRUE))
 ## generators in combination!!!
 
 ## blocks with more than 50 factors
-str.wover(design.info(FrF2(128, 55, blocks=64, alias.block.2fis = TRUE)))
\ No newline at end of file
+str.wover(FrF2(128, 55, blocks=64, alias.block.2fis = TRUE))
\ No newline at end of file
